"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _freeze = require("babel-runtime/core-js/object/freeze");

var _freeze2 = _interopRequireDefault(_freeze);

var _assign = require("babel-runtime/core-js/object/assign");

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require("babel-runtime/helpers/createClass");

var _createClass3 = _interopRequireDefault(_createClass2);

var _path = require("path");

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _cmsConfig = require("./utils/cms.config.file");

var _cmsConfig2 = _interopRequireDefault(_cmsConfig);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable import/no-extraneous-dependencies */
/* covered by nuxt */
var NUXT_CONFIG_KEY = "netlifyCms";
var NUXT_DIST_DIR = "dist";
var CMS_CONFIG_KEY = "cmsConfig";
var CMS_CONFIG_DIR = "netlify-cms";
var CMS_CONFIG_FILENAME = "config.yml";

// Defaults
var DEFAULTS = {
  adminPath: "admin",
  adminTitle: "Content Manager",
  cmsConfig: {
    media_folder: "static/uploads"
  }
};

var ConfigManager = function () {
  function ConfigManager(nuxtOptions, moduleOptions) {
    (0, _classCallCheck3.default)(this, ConfigManager);

    this._relativeSrcDir = (0, _path.relative)(nuxtOptions.rootDir, nuxtOptions.srcDir);

    this._userOptions = (0, _assign2.default)({}, nuxtOptions[NUXT_CONFIG_KEY], moduleOptions);

    var options = _lodash2.default.omit((0, _assign2.default)({}, DEFAULTS, this._userOptions), CMS_CONFIG_KEY);
    options.adminPath = options.adminPath.replace(/\/?$/, "/");
    options.buildDir = (0, _path.join)(nuxtOptions.buildDir, NUXT_DIST_DIR, options.adminPath);
    options.moduleConfigDir = (0, _path.join)(nuxtOptions.srcDir, CMS_CONFIG_DIR);
    this._config = (0, _freeze2.default)(options);

    this._cmsConfigFile = new _cmsConfig2.default((0, _path.join)(this._config.moduleConfigDir, CMS_CONFIG_FILENAME));
  }

  (0, _createClass3.default)(ConfigManager, [{
    key: "readCmsConfigFile",
    value: function readCmsConfigFile() {
      return this._cmsConfigFile.readFile();
    }
  }, {
    key: "config",
    get: function get() {
      return this._config;
    }
  }, {
    key: "cmsConfig",
    get: function get() {
      var config = this.constructor.setConfigPaths((0, _assign2.default)({}, DEFAULTS[CMS_CONFIG_KEY], this._cmsConfigFile.config, this._userOptions[CMS_CONFIG_KEY]), this._relativeSrcDir);
      return config;
    }
  }, {
    key: "cmsConfigFileName",
    get: function get() {
      return this._cmsConfigFile.fileName;
    }
  }], [{
    key: "setConfigPaths",
    value: function setConfigPaths(configObject, enforcedPath) {
      var newConfig = {
        collections: []
      };

      newConfig.media_folder = (0, _path.join)(enforcedPath, configObject.media_folder);

      if (configObject.collections) {
        configObject.collections.forEach(function (collection) {
          if (collection.folder) {
            newConfig.collections.push((0, _assign2.default)({}, collection, {
              folder: (0, _path.join)(enforcedPath, collection.folder)
            }));
          } else if (collection.files) {
            var collectionFiles = [];
            collection.files.forEach(function (fileEntry) {
              fileEntry.file && collectionFiles.push((0, _assign2.default)({}, fileEntry, {
                file: (0, _path.join)(enforcedPath, fileEntry.file)
              }));
            });
            newConfig.collections.push((0, _assign2.default)({}, collection, {
              files: collectionFiles
            }));
          }
        });
      }

      return (0, _assign2.default)({}, configObject, newConfig);
    }
  }]);
  return ConfigManager;
}();

exports.default = ConfigManager;